##  Use Surveys to Collect Data
To collect data from multiple fact sheet owners, create and send a survey. Responses are recorded in the relevant fact sheet fields.
To respond to surveys, users need to be invited to your workspace. You can invite subscribers (contacts) in bulk from the Not invited tab in the Users section of the administration area. If single sign-on (SSO) is enabled in your workspace, you can prevent sending invitation emails by clearing the Send Invitation Email checkbox in the invitation overlay. This prevents notifications, allowing users to stay focused. For more information, see [Contacts](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758f7bb7a4410148ebaeb6edf8d8e3f__contacts).
When creating a survey, do the following:
  1. Filter application fact sheets. You can select applications marked as In scope.
  2. Include these fields in the survey scope:
     * Lifecycle
     * Business criticality
     * Functional fit
     * Technical fit
  3. Add survey recipients by selecting their subscription roles. Ensure recipients are invited to your workspace.


To learn more about using surveys, see [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe1bfd674d5f54c2fb556ffc6ed46e0b8_LowRes.png)
Survey for Collecting Application Attributes
